@@ -46,10 +46,9 @@ static GstStaticPadTemplate gst_rtp_pcmu_depay_sink_template =
     GST_STATIC_CAPS ("application/x-rtp, "
         "media = (string) \"audio\", "
         "payload = (int) " GST_RTP_PAYLOAD_PCMU_STRING ", "
-        "encoding-name = (string) \"PCMU\", clock-rate = (int) 8000; "
+        "clock-rate = (int) 8000; "
         "application/x-rtp, "
         "media = (string) \"audio\", "
-        "payload = (int) " GST_RTP_PAYLOAD_DYNAMIC_STRING ", "
         "encoding-name = (string) \"PCMU\", clock-rate = (int) [1, MAX ]")
     );
 
