@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,11 +24,9 @@
 #include <string.h>
 
 #include <gst/rtp/gstrtpbuffer.h>
-#include <gst/video/video.h>
 
 #include "fnv1hash.h"
 #include "gstrtptheorapay.h"
-#include "gstrtputils.h"
 
 #define THEORA_ID_LEN	42
 
@@ -89,10 +87,6 @@ static GstFlowReturn gst_rtp_theora_pay_handle_buffer (GstRTPBasePayload * pad,
 static gboolean gst_rtp_theora_pay_sink_event (GstRTPBasePayload * payload,
     GstEvent * event);
 
-static gboolean gst_rtp_theora_pay_parse_id (GstRTPBasePayload * basepayload,
-    guint8 * data, guint size);
-static gboolean gst_rtp_theora_pay_finish_headers (GstRTPBasePayload *
-    basepayload);
 
 static void gst_rtp_theora_pay_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec);
@@ -153,18 +147,19 @@ gst_rtp_theora_pay_clear_packet (GstRtpTheoraPay * rtptheorapay)
   if (rtptheorapay->packet)
     gst_buffer_unref (rtptheorapay->packet);
   rtptheorapay->packet = NULL;
-  g_list_free_full (rtptheorapay->packet_buffers,
-      (GDestroyNotify) gst_buffer_unref);
-  rtptheorapay->packet_buffers = NULL;
 }
 
 static void
 gst_rtp_theora_pay_cleanup (GstRtpTheoraPay * rtptheorapay)
 {
-  gst_rtp_theora_pay_clear_packet (rtptheorapay);
-  g_list_free_full (rtptheorapay->headers, (GDestroyNotify) gst_buffer_unref);
+  g_list_foreach (rtptheorapay->headers, (GFunc) gst_mini_object_unref, NULL);
+  g_list_free (rtptheorapay->headers);
   rtptheorapay->headers = NULL;
-  g_free (rtptheorapay->config_data);
+
+  gst_rtp_theora_pay_clear_packet (rtptheorapay);
+
+  if (rtptheorapay->config_data)
+    g_free (rtptheorapay->config_data);
   rtptheorapay->config_data = NULL;
   rtptheorapay->last_config = GST_CLOCK_TIME_NONE;
 }
@@ -173,83 +168,12 @@ static gboolean
 gst_rtp_theora_pay_setcaps (GstRTPBasePayload * basepayload, GstCaps * caps)
 {
   GstRtpTheoraPay *rtptheorapay;
-  GstStructure *s;
-  const GValue *array;
-  gint asize, i;
-  GstBuffer *buf;
-  GstMapInfo map;
 
   rtptheorapay = GST_RTP_THEORA_PAY (basepayload);
 
-  s = gst_caps_get_structure (caps, 0);
-
   rtptheorapay->need_headers = TRUE;
 
-  if ((array = gst_structure_get_value (s, "streamheader")) == NULL)
-    goto done;
-
-  if (G_VALUE_TYPE (array) != GST_TYPE_ARRAY)
-    goto done;
-
-  if ((asize = gst_value_array_get_size (array)) < 3)
-    goto done;
-
-  for (i = 0; i < asize; i++) {
-    const GValue *value;
-
-    value = gst_value_array_get_value (array, i);
-    if ((buf = gst_value_get_buffer (value)) == NULL)
-      goto null_buffer;
-
-    gst_buffer_map (buf, &map, GST_MAP_READ);
-    /* no data packets allowed */
-    if (map.size < 1)
-      goto invalid_streamheader;
-
-    /* we need packets with id 0x80, 0x81, 0x82 */
-    if (map.data[0] != 0x80 + i)
-      goto invalid_streamheader;
-
-    if (i == 0) {
-      /* identification, we need to parse this in order to get the clock rate. */
-      if (G_UNLIKELY (!gst_rtp_theora_pay_parse_id (basepayload, map.data,
-                  map.size)))
-        goto parse_id_failed;
-    }
-    GST_DEBUG_OBJECT (rtptheorapay, "collecting header %d", i);
-    rtptheorapay->headers =
-        g_list_append (rtptheorapay->headers, gst_buffer_ref (buf));
-    gst_buffer_unmap (buf, &map);
-  }
-  if (!gst_rtp_theora_pay_finish_headers (basepayload))
-    goto finish_failed;
-
-done:
   return TRUE;
-
-  /* ERRORS */
-null_buffer:
-  {
-    GST_WARNING_OBJECT (rtptheorapay, "streamheader with null buffer received");
-    return FALSE;
-  }
-invalid_streamheader:
-  {
-    GST_WARNING_OBJECT (rtptheorapay, "unable to parse initial header");
-    gst_buffer_unmap (buf, &map);
-    return FALSE;
-  }
-parse_id_failed:
-  {
-    GST_WARNING_OBJECT (rtptheorapay, "unable to parse initial header");
-    gst_buffer_unmap (buf, &map);
-    return FALSE;
-  }
-finish_failed:
-  {
-    GST_WARNING_OBJECT (rtptheorapay, "unable to finish headers");
-    return FALSE;
-  }
 }
 
 static void
@@ -277,7 +201,8 @@ gst_rtp_theora_pay_init_packet (GstRtpTheoraPay * rtptheorapay, guint8 TDT,
 {
   GST_DEBUG_OBJECT (rtptheorapay, "starting new packet, TDT: %d", TDT);
 
-  gst_rtp_theora_pay_clear_packet (rtptheorapay);
+  if (rtptheorapay->packet)
+    gst_buffer_unref (rtptheorapay->packet);
 
   /* new packet allocate max packet size */
   rtptheorapay->packet =
@@ -285,7 +210,7 @@ gst_rtp_theora_pay_init_packet (GstRtpTheoraPay * rtptheorapay, guint8 TDT,
       (rtptheorapay), 0, 0);
   gst_rtp_theora_pay_reset_packet (rtptheorapay, TDT);
 
-  GST_BUFFER_PTS (rtptheorapay->packet) = timestamp;
+  GST_BUFFER_TIMESTAMP (rtptheorapay->packet) = timestamp;
 }
 
 static GstFlowReturn
@@ -295,7 +220,6 @@ gst_rtp_theora_pay_flush_packet (GstRtpTheoraPay * rtptheorapay)
   guint8 *payload;
   guint hlen;
   GstRTPBuffer rtp = { NULL };
-  GList *l;
 
   /* check for empty packet */
   if (!rtptheorapay->packet || rtptheorapay->payload_pos <= 4)
@@ -333,15 +257,6 @@ gst_rtp_theora_pay_flush_packet (GstRtpTheoraPay * rtptheorapay)
 
   GST_BUFFER_DURATION (rtptheorapay->packet) = rtptheorapay->payload_duration;
 
-  for (l = g_list_last (rtptheorapay->packet_buffers); l; l = l->prev) {
-    GstBuffer *buf = GST_BUFFER_CAST (l->data);
-    gst_rtp_copy_meta (GST_ELEMENT_CAST (rtptheorapay), rtptheorapay->packet,
-        buf, g_quark_from_static_string (GST_META_TAG_VIDEO_STR));
-    gst_buffer_unref (buf);
-  }
-  g_list_free (rtptheorapay->packet_buffers);
-  rtptheorapay->packet_buffers = NULL;
-
   /* push, this gives away our ref to the packet, so clear it. */
   ret =
       gst_rtp_base_payload_push (GST_RTP_BASE_PAYLOAD (rtptheorapay),
@@ -361,7 +276,6 @@ gst_rtp_theora_pay_finish_headers (GstRTPBasePayload * basepayload)
   guint8 *data, *config;
   guint32 ident;
   gboolean res;
-  const gchar *sampling = NULL;
 
   GST_DEBUG_OBJECT (rtptheorapay, "finish headers");
 
@@ -473,6 +387,7 @@ gst_rtp_theora_pay_finish_headers (GstRTPBasePayload * basepayload)
   /* store length for each header */
   for (walk = rtptheorapay->headers; walk; walk = g_list_next (walk)) {
     GstBuffer *buf = GST_BUFFER_CAST (walk->data);
+
     guint bsize, size, temp;
     guint flag;
 
@@ -497,7 +412,7 @@ gst_rtp_theora_pay_finish_headers (GstRTPBasePayload * basepayload)
       size--;
       data[size] = (bsize & 0x7f) | flag;
       bsize >>= 7;
-      flag = 0x80;              /* Flag bit on all bytes of the length except the last */
+      flag = 0x80;
     }
     data += temp;
   }
@@ -505,17 +420,18 @@ gst_rtp_theora_pay_finish_headers (GstRTPBasePayload * basepayload)
   /* copy header data */
   for (walk = rtptheorapay->headers; walk; walk = g_list_next (walk)) {
     GstBuffer *buf = GST_BUFFER_CAST (walk->data);
+    GstMapInfo map;
 
-    gst_buffer_extract (buf, 0, data, gst_buffer_get_size (buf));
-    data += gst_buffer_get_size (buf);
+    gst_buffer_map (buf, &map, GST_MAP_READ);
+    memcpy (data, map.data, map.size);
+    gst_buffer_unmap (buf, &map);
+    data += map.size;
   }
-  rtptheorapay->need_headers = FALSE;
 
   /* serialize to base64 */
   configuration = g_base64_encode (config, configlen);
 
   /* store for later re-sending */
-  g_free (rtptheorapay->config_data);
   rtptheorapay->config_size = configlen - 4 - 3 - 2;
   rtptheorapay->config_data = g_malloc (rtptheorapay->config_size);
   rtptheorapay->config_extra_len = extralen;
@@ -525,27 +441,13 @@ gst_rtp_theora_pay_finish_headers (GstRTPBasePayload * basepayload)
   g_free (config);
 
   /* configure payloader settings */
-  switch (rtptheorapay->pixel_format) {
-    case 2:
-      sampling = "YCbCr-4:2:2";
-      break;
-    case 3:
-      sampling = "YCbCr-4:4:4";
-      break;
-    case 0:
-    default:
-      sampling = "YCbCr-4:2:0";
-      break;
-  }
-
-
   wstr = g_strdup_printf ("%d", rtptheorapay->width);
   hstr = g_strdup_printf ("%d", rtptheorapay->height);
   gst_rtp_base_payload_set_options (basepayload, "video", TRUE, "THEORA",
       90000);
   res =
       gst_rtp_base_payload_set_outcaps (basepayload, "sampling", G_TYPE_STRING,
-      sampling, "width", G_TYPE_STRING, wstr, "height", G_TYPE_STRING,
+      "YCbCr-4:2:0", "width", G_TYPE_STRING, wstr, "height", G_TYPE_STRING,
       hstr, "configuration", G_TYPE_STRING, configuration, "delivery-method",
       G_TYPE_STRING, "inline",
       /* don't set the other defaults 
@@ -570,7 +472,7 @@ gst_rtp_theora_pay_parse_id (GstRTPBasePayload * basepayload, guint8 * data,
     guint size)
 {
   GstRtpTheoraPay *rtptheorapay;
-  gint width, height, pixel_format;
+  gint width, height;
 
   rtptheorapay = GST_RTP_THEORA_PAY (basepayload);
 
@@ -590,12 +492,11 @@ gst_rtp_theora_pay_parse_id (GstRTPBasePayload * basepayload, guint8 * data,
   width = GST_READ_UINT16_BE (data) << 4;
   data += 2;
   height = GST_READ_UINT16_BE (data) << 4;
-  data += 29;
+  data += 2;
 
-  pixel_format = (GST_READ_UINT8 (data) >> 3) & 0x03;
+  /* FIXME, parse pixel format */
 
   /* store values */
-  rtptheorapay->pixel_format = pixel_format;
   rtptheorapay->width = width;
   rtptheorapay->height = height;
 
@@ -625,8 +526,8 @@ invalid_version:
 
 static GstFlowReturn
 gst_rtp_theora_pay_payload_buffer (GstRtpTheoraPay * rtptheorapay, guint8 TDT,
-    GstBuffer * buffer, guint8 * data, guint size, GstClockTime timestamp,
-    GstClockTime duration, guint not_in_length)
+    guint8 * data, guint size, GstClockTime timestamp, GstClockTime duration,
+    guint not_in_length)
 {
   GstFlowReturn ret = GST_FLOW_OK;
   guint newsize;
@@ -657,9 +558,6 @@ gst_rtp_theora_pay_payload_buffer (GstRtpTheoraPay * rtptheorapay, guint8 TDT,
   if (flush)
     ret = gst_rtp_theora_pay_flush_packet (rtptheorapay);
 
-  if (ret != GST_FLOW_OK)
-    goto done;
-
   /* create new packet if we must */
   if (!rtptheorapay->packet) {
     gst_rtp_theora_pay_init_packet (rtptheorapay, TDT, timestamp);
@@ -683,21 +581,6 @@ gst_rtp_theora_pay_payload_buffer (GstRtpTheoraPay * rtptheorapay, guint8 TDT,
     if (plen)
       memcpy (&ppos[2], data, plen);
 
-    if (buffer) {
-      if (!rtptheorapay->packet_buffers
-          || rtptheorapay->packet_buffers->data != (gpointer) buffer)
-        rtptheorapay->packet_buffers =
-            g_list_prepend (rtptheorapay->packet_buffers,
-            gst_buffer_ref (buffer));
-    } else {
-      GList *l;
-
-      for (l = rtptheorapay->headers; l; l = l->next)
-        rtptheorapay->packet_buffers =
-            g_list_prepend (rtptheorapay->packet_buffers,
-            gst_buffer_ref (l->data));
-    }
-
     /* only first (only) configuration cuts length field */
     /* NOTE: spec (if any) is not clear on this ... */
     not_in_length = 0;
@@ -724,9 +607,9 @@ gst_rtp_theora_pay_payload_buffer (GstRtpTheoraPay * rtptheorapay, guint8 TDT,
       }
     }
     if (fragmented) {
-      gst_rtp_buffer_unmap (&rtp);
       /* fragmented packets are always flushed and have ptks of 0 */
       rtptheorapay->payload_pkts = 0;
+      gst_rtp_buffer_unmap (&rtp);
       ret = gst_rtp_theora_pay_flush_packet (rtptheorapay);
 
       if (size > 0) {
@@ -744,11 +627,10 @@ gst_rtp_theora_pay_payload_buffer (GstRtpTheoraPay * rtptheorapay, guint8 TDT,
       if (duration != GST_CLOCK_TIME_NONE)
         rtptheorapay->payload_duration += duration;
     }
-  } while (size && ret == GST_FLOW_OK);
+  } while (size);
 
   if (rtp.buffer)
     gst_rtp_buffer_unmap (&rtp);
-done:
 
   return ret;
 }
@@ -772,11 +654,14 @@ gst_rtp_theora_pay_handle_buffer (GstRTPBasePayload * basepayload,
   data = map.data;
   size = map.size;
   duration = GST_BUFFER_DURATION (buffer);
-  timestamp = GST_BUFFER_PTS (buffer);
+  timestamp = GST_BUFFER_TIMESTAMP (buffer);
 
   GST_DEBUG_OBJECT (rtptheorapay, "size %" G_GSIZE_FORMAT
       ", duration %" GST_TIME_FORMAT, size, GST_TIME_ARGS (duration));
 
+  if (G_UNLIKELY (size > 0xffff))
+    goto wrong_size;
+
   /* find packet type */
   if (size == 0) {
     TDT = 0;
@@ -803,17 +688,20 @@ gst_rtp_theora_pay_handle_buffer (GstRTPBasePayload * basepayload,
     keyframe = ((data[0] & 0x40) == 0);
   }
 
-  /* we need to collect the headers and construct a config string from them */
-  if (TDT != 0) {
-    GST_DEBUG_OBJECT (rtptheorapay, "collecting header, buffer %p", buffer);
-    /* append header to the list of headers */
-    gst_buffer_unmap (buffer, &map);
-    rtptheorapay->headers = g_list_append (rtptheorapay->headers, buffer);
-    ret = GST_FLOW_OK;
-    goto done;
-  } else if (rtptheorapay->headers && rtptheorapay->need_headers) {
-    if (!gst_rtp_theora_pay_finish_headers (basepayload))
-      goto header_error;
+  if (rtptheorapay->need_headers) {
+    /* we need to collect the headers and construct a config string from them */
+    if (TDT != 0) {
+      GST_DEBUG_OBJECT (rtptheorapay, "collecting header, buffer %p", buffer);
+      /* append header to the list of headers */
+      gst_buffer_unmap (buffer, &map);
+      rtptheorapay->headers = g_list_append (rtptheorapay->headers, buffer);
+      ret = GST_FLOW_OK;
+      goto done;
+    } else {
+      if (!gst_rtp_theora_pay_finish_headers (basepayload))
+        goto header_error;
+      rtptheorapay->need_headers = FALSE;
+    }
   }
 
   /* there is a config request, see if we need to insert it */
@@ -854,7 +742,7 @@ gst_rtp_theora_pay_handle_buffer (GstRTPBasePayload * basepayload,
       /* we need to send config now first */
       /* different TDT type forces flush */
       gst_rtp_theora_pay_payload_buffer (rtptheorapay, 1,
-          NULL, rtptheorapay->config_data, rtptheorapay->config_size,
+          rtptheorapay->config_data, rtptheorapay->config_size,
           timestamp, GST_CLOCK_TIME_NONE, rtptheorapay->config_extra_len);
 
       if (timestamp != -1) {
@@ -863,8 +751,7 @@ gst_rtp_theora_pay_handle_buffer (GstRTPBasePayload * basepayload,
     }
   }
 
-  ret =
-      gst_rtp_theora_pay_payload_buffer (rtptheorapay, TDT, buffer, data, size,
+  ret = gst_rtp_theora_pay_payload_buffer (rtptheorapay, TDT, data, size,
       timestamp, duration, 0);
 
   gst_buffer_unmap (buffer, &map);
@@ -874,6 +761,14 @@ done:
   return ret;
 
   /* ERRORS */
+wrong_size:
+  {
+    GST_ELEMENT_WARNING (rtptheorapay, STREAM, DECODE,
+        ("Invalid packet size (%" G_GSIZE_FORMAT " <= 0xffff)", size), (NULL));
+    gst_buffer_unmap (buffer, &map);
+    gst_buffer_unref (buffer);
+    return GST_FLOW_OK;
+  }
 parse_id_failed:
   {
     gst_buffer_unmap (buffer, &map);
