@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_VIDEO_FLIP_H__
@@ -36,7 +36,6 @@ G_BEGIN_DECLS
  * @GST_VIDEO_FLIP_METHOD_VERT: Flip vertically
  * @GST_VIDEO_FLIP_METHOD_TRANS: Flip across upper left/lower right diagonal
  * @GST_VIDEO_FLIP_METHOD_OTHER: Flip across upper right/lower left diagonal
- * @GST_VIDEO_FLIP_METHOD_AUTO: Select flip method based on image-orientation tag
  *
  * The different flip methods.
  */
@@ -48,8 +47,7 @@ typedef enum {
   GST_VIDEO_FLIP_METHOD_HORIZ,
   GST_VIDEO_FLIP_METHOD_VERT,
   GST_VIDEO_FLIP_METHOD_TRANS,
-  GST_VIDEO_FLIP_METHOD_OTHER,
-  GST_VIDEO_FLIP_METHOD_AUTO
+  GST_VIDEO_FLIP_METHOD_OTHER
 } GstVideoFlipMethod;
 
 #define GST_TYPE_VIDEO_FLIP \
@@ -75,14 +73,7 @@ struct _GstVideoFlip {
   GstVideoFilter videofilter;
 
   /* < private > */
-  GstVideoFormat v_format;
-
-  GstVideoOrientationMethod method;
-  GstVideoOrientationMethod tag_method;
-  GstVideoOrientationMethod proposed_method;
-  gboolean change_configuring_method;
-  GstVideoOrientationMethod configuring_method;
-  GstVideoOrientationMethod active_method;
+  GstVideoFlipMethod method;
   void (*process) (GstVideoFlip *videoflip, GstVideoFrame *dest, const GstVideoFrame *src);
 };
 
@@ -92,8 +83,6 @@ struct _GstVideoFlipClass {
 
 GType gst_video_flip_get_type (void);
 
-GST_ELEMENT_REGISTER_DECLARE (videoflip);
-
 G_END_DECLS
 
 #endif /* __GST_VIDEO_FLIP_H__ */
